@@ -939,6 +939,9 @@ private slots:
 		log_debug("ws: connected");
 
 		QByteArray path = requestUri.path(QUrl::FullyEncoded).toUtf8();
+		if(path.isEmpty())
+			path = "/";
+
 		if(requestUri.hasQuery())
 			path += '?' + requestUri.query(QUrl::FullyEncoded).toUtf8();
 
@@ -1081,6 +1084,15 @@ private slots:
 				curError = ErrorConnect;
 				break;
 			case QAbstractSocket::RemoteHostClosedError:
+				if(state == Closing && peerClosing)
+				{
+					// we should not get this error in
+					// this state, but if we do, ignore
+					// it. the disconnected signal will
+					// come soon after
+					return;
+				}
+
 				if(readingResponseBody && responseContentLength == -1 && !chunked)
 				{
 					handleResponse();
